==> aidge_onnx-0.5.0-py3-none-any.whl: aidge_onnx/node_import/onnx_converters/reshape.py <==
"""
Copyright (c) 2023 CEA-List

This program and the accompanying materials are made available under the
terms of the Eclipse Public License 2.0 which is available at
http://www.eclipse.org/legal/epl-2.0.

SPDX-License-Identifier: EPL-2.0
"""
from typing import List, Tuple

import aidge_core
import onnx

from aidge_onnx.node_import import auto_register_import
from aidge_onnx.utils import get_node_attributes

from aidge_core import Log

@auto_register_import("reshape")
def import_reshape(onnx_node:onnx.NodeProto, input_nodes:List[Tuple[aidge_core.Node, int]], opset=None) -> aidge_core.Node:
    """
    :param onnx_node: ONNX node to convert
    :type onnx_node: onnx.NodeProto
    :param input_nodes: List of Aidge nodes which constitute the input of the current node
    :type input_nodes: List[aidge_core.Node]
    :param opset: Indicate opset version of the ONNX model, default=None
    :type opset: int, optional
    """
    node_name = onnx_node.name if onnx_node.name else onnx_node.output[0]
    onnx_attrs = get_node_attributes(onnx_node, opset)
    reshape_attrs : dict = {"allowzero" : False, "name" : node_name}# + conditional attr shape

    if opset >= 14 and 'allowzero' in onnx_attrs:
        reshape_attrs['allowzero'] = onnx_attrs['allowzero']
        del onnx_attrs['allowzero']

    if opset < 5:
        if 'consumed_inputs' in onnx_attrs:
            #legacy optimisation attribute
            del onnx_attrs['consumed_inputs']

        if 'shape' in onnx_attrs:
            reshape_attrs["shape"] = onnx_attrs['shape']
            del onnx_attrs['shape']
    else:
        if input_nodes[1] is not None:
            reshape_attrs['shape'] = input_nodes[1][0].get_operator().get_output(input_nodes[1][1])

    if len(onnx_attrs) > 0:
        Log.warn(f"Warning: unsupported attribute(s): {onnx_attrs.keys()} for operator 'Reshape' with opset {opset}.\nThis node will be filled by a GenericOperator.")
        return None

    my_node = aidge_core.Reshape(**reshape_attrs)
    Log.info(f"Loaded node [\033[1m\033[3m{node_name}\033[0m] of type [\033[1m\033[3m{onnx_node.op_type}\033[0m]")
    return my_node

==> aidge_onnx-0.5.1-py3-none-any.whl: aidge_onnx/node_import/onnx_converters/reshape.py <==
"""
Copyright (c) 2023 CEA-List

This program and the accompanying materials are made available under the
terms of the Eclipse Public License 2.0 which is available at
http://www.eclipse.org/legal/epl-2.0.

SPDX-License-Identifier: EPL-2.0
"""
from typing import List, Tuple, Optional

import aidge_core
import onnx
from onnx import NodeProto

from aidge_onnx.node_import import auto_register_import
from aidge_onnx.utils import get_node_attributes

from aidge_core import Log

@auto_register_import("reshape")
def import_reshape(onnx_node: NodeProto, input_nodes: List[Tuple[aidge_core.Node, int]], opset: Optional[int] = None) -> aidge_core.Node:
    """
    :param onnx_node: ONNX node to convert
    :type onnx_node: onnx.NodeProto
    :param input_nodes: List of Aidge nodes which constitute the input of the current node
    :type input_nodes: List[aidge_core.Node]
    :param opset: Indicate opset version of the ONNX model, default=None
    :type opset: int, optional
    """
    node_name = onnx_node.name if onnx_node.name else onnx_node.output[0]
    onnx_attrs = get_node_attributes(onnx_node, opset)
    reshape_attrs : dict = {"allowzero" : False, "name" : node_name}# + conditional attr shape

    if opset >= 14 and 'allowzero' in onnx_attrs:
        reshape_attrs['allowzero'] = onnx_attrs['allowzero']
        del onnx_attrs['allowzero']

    if opset < 5:
        if 'consumed_inputs' in onnx_attrs:
            #legacy optimisation attribute
            del onnx_attrs['consumed_inputs']

        if 'shape' in onnx_attrs:
            reshape_attrs["shape"] = onnx_attrs['shape']
            del onnx_attrs['shape']
    else:
        if input_nodes[1] is not None:
            reshape_attrs['shape'] = input_nodes[1][0].get_operator().get_output(input_nodes[1][1])

    if len(onnx_attrs) > 0:
        Log.warn(f"Warning: unsupported attribute(s): {onnx_attrs.keys()} for operator 'Reshape' with opset {opset}.\nThis node will be filled by a GenericOperator.")
        return None

    my_node = aidge_core.Reshape(**reshape_attrs)
    Log.info(f"Loaded node [\033[1m\033[3m{node_name}\033[0m] of type [\033[1m\033[3m{onnx_node.op_type}\033[0m]")
    return my_node
